@@ -272,10 +272,9 @@ module AWS
 
         def shared_credential_file_path
           if RUBY_VERSION < '1.9'
-            raise ArgumentError(
-              "Must specify the :path to your shared credential file when using"\
-                " Ruby #{RUBY_VERSION}"
-            )
+            msg = "Must specify the :path to your shared credential file when using"
+            msg << " Ruby #{RUBY_VERSION}"
+            raise ArgumentError, msg
           else
             File.join(Dir.home, '.aws', 'credentials')
           end
@@ -355,6 +354,8 @@ module AWS
         # @param [Hash] options
         # @option options [String] :ip_address ('169.254.169.254')
         # @option options [Integer] :port (80)
+        # @option options [Integer] :retries (0) Number of times to
+        #   retry retrieving credentials.
         # @option options [Float] :http_open_timeout (1)
         # @option options [Float] :http_read_timeout (1)
         # @option options [Object] :http_debug_output (nil) HTTP wire
@@ -363,6 +364,7 @@ module AWS
         def initialize options = {}
           @ip_address = options[:ip_address] || '169.254.169.254'
           @port = options[:port] || 80
+          @retries = options[:retries] || 0
           @http_open_timeout = options[:http_open_timeout] || 1
           @http_read_timeout = options[:http_read_timeout] || 1
           @http_debug_output = options[:http_debug_output]
@@ -374,6 +376,9 @@ module AWS
         # @return [Integer] Defaults to port 80.
         attr_accessor :port
 
+        # @return [Integer] Defaults to 0
+        attr_accessor :retries
+
         # @return [Float]
         attr_accessor :http_open_timeout
 
@@ -386,7 +391,7 @@ module AWS
         # @return [Time,nil]
         attr_accessor :credentials_expiration
 
-        # Refresh provider if existing credentials will be expired in 5 min
+        # Refresh provider if existing credentials will be expired in 15 min
         # @return [Hash] Returns a hash of credentials containg at least
         #   the `:access_key_id` and `:secret_access_key`.  The hash may
         #   also contain a `:session_token`.
@@ -405,6 +410,8 @@ module AWS
 
         # (see Provider#get_credentials)
         def get_credentials
+          retries_left = retries
+
           begin
 
             http = Net::HTTP.new(ip_address, port, nil)
@@ -433,7 +440,15 @@ module AWS
             credentials
 
           rescue *FAILURES => e
-            {}
+            if retries_left > 0
+              sleep_time = 2 ** (retries - retries_left)
+              Kernel.sleep(sleep_time)
+
+              retries_left -= 1
+              retry
+            else
+              {}
+            end
           end
         end
 
@@ -567,7 +582,7 @@ module AWS
 
         include Provider
 
-        # @option options [AWS::STS] :sts (STS.new) An instance of {AWS::STS}. 
+        # @option options [AWS::STS] :sts (STS.new) An instance of {AWS::STS}.
         #   This is used to make the API call to assume role.
         # @option options [required, String] :role_arn
         # @option options [required, String] :role_session_name
